Crate ark_ed_on_mnt4_298

Crate ark_ed_on_mnt4_298 

This library implements a twisted Edwards curve whose base field is the scalar field of the curve MNT4-298. This allows defining cryptographic primitives that use elliptic curves over the scalar field of the latter curve.

Curve information:

  • Base field: q = 475922286169261325753349249653048451545124878552823515553267735739164647307408490559963137
  • Scalar field: r = 118980571542315331438337312413262112886281219744507561120271964887686106682370032123932631
  • Valuation(q - 1, 2) = 30
  • Valuation(r - 1, 2) = 1
  • Curve equation: ax^2 + y^2 =1 + dx^2y^2, where
    • a = -1
    • d = 4212 mod q

Modules

fq
fr

Structs

EdwardsConfig
FqConfig
FrConfig

Constants

GENERATOR_X
GENERATOR_X = 282406820114868156776872298252698015906762052916420164316497572033519876761239463633892227
GENERATOR_Y
GENERATOR_Y = 452667754940241021433619311795265643711152068500301853535337412655162600774122192283142703

Type Aliases

EdwardsAffine
EdwardsProjective
Fq
Fr